Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(16)

Unified Diff: chrome/browser/password_manager/chrome_password_manager_client.h

Issue 1850923004: Disable the autofill password manager when a credential is sent via CM API. (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: comments Created 4 years, 8 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « no previous file | chrome/browser/password_manager/chrome_password_manager_client.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: chrome/browser/password_manager/chrome_password_manager_client.h
diff --git a/chrome/browser/password_manager/chrome_password_manager_client.h b/chrome/browser/password_manager/chrome_password_manager_client.h
index bc8c97327559908634c0bd873c0c6e63f9d89b4b..fa856910d001ce1c887bde94f625e85b22ee45ab 100644
--- a/chrome/browser/password_manager/chrome_password_manager_client.h
+++ b/chrome/browser/password_manager/chrome_password_manager_client.h
@@ -155,9 +155,11 @@ class ChromePasswordManagerClient
// for UMA stats.
void GenerationAvailableForForm(const autofill::PasswordForm& form);
// Called as a response to PromptUserToChooseCredentials. nullptr means that
// nothing was chosen.
void OnCredentialsChosen(const CredentialsCallback& callback,
+ bool one_local_credential,
const autofill::PasswordForm* form);
Profile* const profile_;
« no previous file with comments | « no previous file | chrome/browser/password_manager/chrome_password_manager_client.cc » ('j') | no next file with comments »
@@ -155,9 +155,11 @@ class ChromePasswordManagerClient
// for UMA stats.
void GenerationAvailableForForm(const autofill::PasswordForm& form);
- // Called as a response to PromptUserToChooseCredentials. nullptr means that
- // nothing was chosen.
+ // Called as a response to PromptUserToChooseCredentials. nullptr in |form|
+ // means that nothing was chosen. |one_local_credential| is true if there was
+ // just one local credential to be chosen from.
void OnCredentialsChosen(const CredentialsCallback& callback,

Powered by Google App Engine
This is Rietveld 408576698